Many minor typo fixes

Message ID 20250403143559.360766-1-tromey@adacore.com
State New
Headers
Series Many minor typo fixes |

Checks

Context Check Description
linaro-tcwg-bot/tcwg_gdb_build--master-aarch64 fail Patch failed to apply
linaro-tcwg-bot/tcwg_gdb_build--master-arm fail Patch failed to apply

Commit Message

Tom Tromey April 3, 2025, 2:35 p.m. UTC
  I ran codespell on gdb/*.[chyl] and fixed a bunch of simple typos.
Most of what remains is trickier, i.e., spots where a somewhat natural
name of something in the code is flagged as a typo.
---
 gdb/aarch64-tdep.c         |  4 ++--
 gdb/ada-lang.c             | 12 ++++++------
 gdb/ada-varobj.c           |  8 ++++----
 gdb/alpha-tdep.c           |  2 +-
 gdb/amd64-fbsd-nat.c       |  4 ++--
 gdb/amd64-tdep.c           |  2 +-
 gdb/arm-linux-nat.c        |  2 +-
 gdb/arm-tdep.c             |  4 ++--
 gdb/bcache.c               |  2 +-
 gdb/bcache.h               |  2 +-
 gdb/bfin-tdep.c            |  2 +-
 gdb/bpf-tdep.c             |  2 +-
 gdb/breakpoint.h           |  2 +-
 gdb/btrace.c               | 14 +++++++-------
 gdb/buildsym.h             |  2 +-
 gdb/coffread.c             |  2 +-
 gdb/command.h              |  2 +-
 gdb/completer.c            |  2 +-
 gdb/completer.h            |  2 +-
 gdb/cp-namespace.c         |  2 +-
 gdb/cp-valprint.c          |  2 +-
 gdb/cris-tdep.c            |  4 ++--
 gdb/csky-tdep.c            |  4 ++--
 gdb/displaced-stepping.h   |  2 +-
 gdb/dtrace-probe.c         |  2 +-
 gdb/elfread.c              |  2 +-
 gdb/frame-base.h           |  2 +-
 gdb/frame.h                |  2 +-
 gdb/ft32-tdep.c            |  2 +-
 gdb/gdbarch.h              |  2 +-
 gdb/gdbthread.h            |  4 ++--
 gdb/gnu-v3-abi.c           |  2 +-
 gdb/h8300-tdep.c           |  2 +-
 gdb/hppa-linux-tdep.c      |  2 +-
 gdb/i386-fbsd-nat.c        |  4 ++--
 gdb/i386-sol2-nat.c        |  2 +-
 gdb/i386-tdep.c            |  4 ++--
 gdb/ia64-tdep.c            |  8 ++++----
 gdb/ia64-vms-tdep.c        |  2 +-
 gdb/inf-loop.c             |  2 +-
 gdb/infcall.c              |  2 +-
 gdb/infrun.c               |  2 +-
 gdb/iq2000-tdep.c          |  2 +-
 gdb/linux-nat.c            |  4 ++--
 gdb/linux-tdep.c           |  4 ++--
 gdb/loongarch-linux-tdep.c |  2 +-
 gdb/machoread.c            |  2 +-
 gdb/main.c                 |  2 +-
 gdb/mdebugread.c           |  8 ++++----
 gdb/mips-tdep.c            |  2 +-
 gdb/moxie-tdep.c           |  2 +-
 gdb/nds32-tdep.c           |  2 +-
 gdb/p-exp.y                |  2 +-
 gdb/record-full.c          |  4 ++--
 gdb/remote.c               |  2 +-
 gdb/riscv-tdep.c           |  2 +-
 gdb/rs6000-tdep.c          |  4 ++--
 gdb/run-on-main-thread.c   |  2 +-
 gdb/s390-tdep.c            |  4 ++--
 gdb/ser-mingw.c            |  4 ++--
 gdb/ser-unix.c             |  2 +-
 gdb/solib-rocm.c           |  2 +-
 gdb/solib.c                |  2 +-
 gdb/sparc-obsd-tdep.c      |  2 +-
 gdb/sparc-sol2-nat.c       |  2 +-
 gdb/sparc64-obsd-tdep.c    |  2 +-
 gdb/stabsread.c            | 10 +++++-----
 gdb/stabsread.h            |  2 +-
 gdb/stack.c                |  2 +-
 gdb/stap-probe.c           |  2 +-
 gdb/symfile.c              |  2 +-
 gdb/symtab.c               |  2 +-
 gdb/top.c                  |  2 +-
 gdb/utils.c                |  2 +-
 gdb/value.c                |  8 ++++----
 gdb/value.h                |  2 +-
 gdb/varobj.c               |  2 +-
 gdb/vax-tdep.c             |  2 +-
 gdb/windows-nat.h          |  4 ++--
 gdb/xcoffread.c            |  4 ++--
 gdb/xstormy16-tdep.c       |  2 +-
 gdb/xtensa-tdep.c          |  2 +-
 82 files changed, 125 insertions(+), 125 deletions(-)


base-commit: abf215a338f2e2afdea78d629cd049a3e59348b8
  

Comments

Tom de Vries April 3, 2025, 3:34 p.m. UTC | #1
On 4/3/25 16:35, Tom Tromey wrote:
> -   This is a rather nasty bit of code searchs for the .dynamic section
> +   This is a rather nasty bit of code searches for the .dynamic section

Hi Tom,

thanks for doing this.

Pre-existing, but:

"This is a rather nasty bit of code searches"

  ->

"This rather nasty bit of code searches"

?

This seems to occur a couple of times.

Also:
...
-	  /* No useable line symbol.  Use result of prologue parsing
+	  /* No useble line symbol.  Use result of prologue parsing
...

This should probably be usable.

Otherwise LGTM.

Reviewed-By: Tom de Vries <tdevries@suse.de>

Thanks,
- Tom
  
Tom Tromey April 3, 2025, 4:56 p.m. UTC | #2
>>>>> "Tom" == Tom de Vries <tdevries@suse.de> writes:

Tom> Pre-existing, but:
Tom> "This is a rather nasty bit of code searches"
-> 
Tom> "This rather nasty bit of code searches"
Tom> ?

Yeah, I fixed this, thanks.

Tom> Also:
Tom> ...
Tom> -	  /* No useable line symbol.  Use result of prologue parsing
Tom> +	  /* No useble line symbol.  Use result of prologue parsing
Tom> ...

Tom> This should probably be usable.

Yep, oops.

I'm checking this in now.

Tom
  

Patch

diff --git a/gdb/aarch64-tdep.c b/gdb/aarch64-tdep.c
index bd107b8ce3a..0561c937461 100644
--- a/gdb/aarch64-tdep.c
+++ b/gdb/aarch64-tdep.c
@@ -2696,7 +2696,7 @@  aarch64_store_return_value (struct type *type, struct regcache *regs,
 	{
 	  /* Integral values greater than one word are stored in
 	     consecutive registers starting with r0.  This will always
-	     be a multiple of the regiser size.  */
+	     be a multiple of the register size.  */
 	  int len = type->length ();
 	  int regno = AARCH64_X0_REGNUM;
 
@@ -4344,7 +4344,7 @@  aarch64_initialize_sme_pseudo_names (struct gdbarch *gdbarch,
 }
 
 /* Initialize the current architecture based on INFO.  If possible,
-   re-use an architecture from ARCHES, which is a list of
+   reuse an architecture from ARCHES, which is a list of
    architectures already created during this debugging session.
 
    Called e.g. at program startup, when reading a core file, and when
diff --git a/gdb/ada-lang.c b/gdb/ada-lang.c
index a55ee12ce70..041024adaa9 100644
--- a/gdb/ada-lang.c
+++ b/gdb/ada-lang.c
@@ -1532,7 +1532,7 @@  ada_decode (const char *encoded, bool wrap, bool operators, bool wide)
 	{
 	  /* This is a X[bn]* sequence not separated from the previous
 	     part of the name with a non-alpha-numeric character (in other
-	     words, immediately following an alpha-numeric character), then
+	     words, immediately following an alphanumeric character), then
 	     verify that it is placed at the end of the encoded name.  If
 	     not, then the encoding is not valid and we should abort the
 	     decoding.  Otherwise, just skip it, it is used in body-nested
@@ -3047,7 +3047,7 @@  ada_value_subscript (struct value *arr, int arity, struct value **ind)
 
    Note: Unlike what one would expect, this function is used instead of
    ada_value_subscript for basically all non-packed array types.  The reason
-   for this is that a side effect of doing our own pointer arithmetics instead
+   for this is that a side effect of doing our own pointer arithmetic instead
    of relying on value_subscript is that there is no implicit typedef peeling.
    This is important for arrays of array accesses, where it allows us to
    preserve the fact that the array's element is an array access, where the
@@ -5435,7 +5435,7 @@  ada_add_block_renamings (std::vector<struct block_symbol> &result,
 	 better in this case since, in DWARF, DW_AT_import is a DIE reference,
 	 not a simple name.  But in order to do this, we would need to enhance
 	 the DWARF reader to associate a symbol to this renaming, instead of a
-	 name.  So, for now, we do something simpler: re-use the C++/Fortran
+	 name.  So, for now, we do something simpler: reuse the C++/Fortran
 	 namespace machinery.  */
       r_name = (renaming->alias != NULL
 		? renaming->alias
@@ -9802,7 +9802,7 @@  ada_value_cast (struct type *type, struct value *arg2)
     The following description is a general guide as to what should be
     done (and what should NOT be done) in order to evaluate an expression
     involving such types, and when.  This does not cover how the semantic
-    information is encoded by GNAT as this is covered separatly.  For the
+    information is encoded by GNAT as this is covered separately.  For the
     document used as the reference for the GNAT encoding, see exp_dbug.ads
     in the GNAT sources.
 
@@ -11780,14 +11780,14 @@  ada_exception_support_info_sniffer (void)
       return;
     }
 
-  /* Try the v0 exception suport info.  */
+  /* Try the v0 exception support info.  */
   if (ada_has_this_exception_support (&exception_support_info_v0))
     {
       data->exception_info = &exception_support_info_v0;
       return;
     }
 
-  /* Try our fallback exception suport info.  */
+  /* Try our fallback exception support info.  */
   if (ada_has_this_exception_support (&exception_support_info_fallback))
     {
       data->exception_info = &exception_support_info_fallback;
diff --git a/gdb/alpha-tdep.c b/gdb/alpha-tdep.c
index 7201b724a9e..bf3e8fc32a4 100644
--- a/gdb/alpha-tdep.c
+++ b/gdb/alpha-tdep.c
@@ -1705,7 +1705,7 @@  alpha_software_single_step (struct regcache *regcache)
 }
 
 
-/* Initialize the current architecture based on INFO.  If possible, re-use an
+/* Initialize the current architecture based on INFO.  If possible, reuse an
    architecture from ARCHES, which is a list of architectures already created
    during this debugging session.
 
diff --git a/gdb/amd64-fbsd-nat.c b/gdb/amd64-fbsd-nat.c
index 6ce7c45b8b3..613f2753d9b 100644
--- a/gdb/amd64-fbsd-nat.c
+++ b/gdb/amd64-fbsd-nat.c
@@ -137,7 +137,7 @@  amd64_fbsd_nat_target::fetch_registers (struct regcache *regcache, int regnum)
 
   /* There is no amd64_fxsave_supplies or amd64_xsave_supplies.
      Instead, the earlier register sets return early if the request
-     was for a specific register that was already satisified to avoid
+     was for a specific register that was already satisfied to avoid
      fetching the FPU/XSAVE state unnecessarily.  */
 
 #ifdef PT_GETXSTATE_INFO
@@ -214,7 +214,7 @@  amd64_fbsd_nat_target::store_registers (struct regcache *regcache, int regnum)
 
   /* There is no amd64_fxsave_supplies or amd64_xsave_supplies.
      Instead, the earlier register sets return early if the request
-     was for a specific register that was already satisified to avoid
+     was for a specific register that was already satisfied to avoid
      fetching the FPU/XSAVE state unnecessarily.  */
 
 #ifdef PT_GETXSTATE_INFO
diff --git a/gdb/amd64-tdep.c b/gdb/amd64-tdep.c
index bebfd0d4449..3c58b85545a 100644
--- a/gdb/amd64-tdep.c
+++ b/gdb/amd64-tdep.c
@@ -2608,7 +2608,7 @@  amd64_skip_xmm_prologue (CORE_ADDR pc, CORE_ADDR start_pc)
   if (next_sal.line != start_pc_sal.line)
     return pc;
 
-  /* START_PC can be from overlayed memory, ignored here.  */
+  /* START_PC can be from overlay memory, ignored here.  */
   if (target_read_code (next_sal.pc - 4, buf, sizeof (buf)) != 0)
     return pc;
 
diff --git a/gdb/arm-linux-nat.c b/gdb/arm-linux-nat.c
index 7b4faacd601..1aa591a9cbc 100644
--- a/gdb/arm-linux-nat.c
+++ b/gdb/arm-linux-nat.c
@@ -714,7 +714,7 @@  struct arm_linux_hw_breakpoint
 
    The Linux ptrace interface to hardware break-/watch-points presents the 
    values in a vector centred around 0 (which is used fo generic information).
-   Positive indicies refer to breakpoint addresses/control registers, negative
+   Positive indices refer to breakpoint addresses/control registers, negative
    indices to watchpoint addresses/control registers.
 
    The Linux vector is indexed as follows:
diff --git a/gdb/arm-tdep.c b/gdb/arm-tdep.c
index 879f5cf2447..b985ca89049 100644
--- a/gdb/arm-tdep.c
+++ b/gdb/arm-tdep.c
@@ -9202,7 +9202,7 @@  arm_store_return_value (struct type *type, struct regcache *regs,
 	{
 	  /* Integral values greater than one word are stored in consecutive
 	     registers starting with r0.  This will always be a multiple of
-	     the regiser size.  */
+	     the register size.  */
 	  int len = type->length ();
 	  int regno = ARM_A1_REGNUM;
 
@@ -10103,7 +10103,7 @@  arm_get_pc_address_flags (const frame_info_ptr &frame, CORE_ADDR pc)
 }
 
 /* Initialize the current architecture based on INFO.  If possible,
-   re-use an architecture from ARCHES, which is a list of
+   reuse an architecture from ARCHES, which is a list of
    architectures already created during this debugging session.
 
    Called e.g. at program startup, when reading a core file, and when
diff --git a/gdb/bcache.c b/gdb/bcache.c
index a9aab28ab84..fe2c76d23f3 100644
--- a/gdb/bcache.c
+++ b/gdb/bcache.c
@@ -250,7 +250,7 @@  print_percentage (int portion, int total)
 }
 
 
-/* Print statistics on BCACHE's memory usage and efficacity at
+/* Print statistics on BCACHE's memory usage and efficacy at
    eliminating duplication.  NAME should describe the kind of data
    BCACHE holds.  Statistics are printed using `gdb_printf' and
    its ilk.  */
diff --git a/gdb/bcache.h b/gdb/bcache.h
index 82cdd13cf6f..2e05a15c079 100644
--- a/gdb/bcache.h
+++ b/gdb/bcache.h
@@ -173,7 +173,7 @@  struct bcache
 				     added);
   }
 
-  /* Print statistics on this bcache's memory usage and efficacity at
+  /* Print statistics on this bcache's memory usage and efficacy at
      eliminating duplication.  TYPE should be a string describing the
      kind of data this bcache holds.  Statistics are printed using
      `gdb_printf' and its ilk.  */
diff --git a/gdb/bfin-tdep.c b/gdb/bfin-tdep.c
index 78ade80ad25..f8294edfcf3 100644
--- a/gdb/bfin-tdep.c
+++ b/gdb/bfin-tdep.c
@@ -769,7 +769,7 @@  bfin_abi (struct gdbarch *gdbarch)
 }
 
 /* Initialize the current architecture based on INFO.  If possible,
-   re-use an architecture from ARCHES, which is a list of
+   reuse an architecture from ARCHES, which is a list of
    architectures already created during this debugging session.
 
    Called e.g. at program startup, when reading a core file, and when
diff --git a/gdb/bpf-tdep.c b/gdb/bpf-tdep.c
index 8f3e50d86c1..41c973833f4 100644
--- a/gdb/bpf-tdep.c
+++ b/gdb/bpf-tdep.c
@@ -307,7 +307,7 @@  bpf_return_value (struct gdbarch *gdbarch, struct value *function,
 }
 
 
-/* Initialize the current architecture based on INFO.  If possible, re-use an
+/* Initialize the current architecture based on INFO.  If possible, reuse an
    architecture from ARCHES, which is a list of architectures already created
    during this debugging session.  */
 
diff --git a/gdb/breakpoint.h b/gdb/breakpoint.h
index 94fba1cf602..ec3a1284320 100644
--- a/gdb/breakpoint.h
+++ b/gdb/breakpoint.h
@@ -1740,7 +1740,7 @@  extern void disable_overlay_breakpoints (void);
 extern void set_std_terminate_breakpoint (void);
 extern void delete_std_terminate_breakpoint (void);
 
-/* These functions respectively disable or reenable all currently
+/* These functions respectively disable or re-enable all currently
    enabled watchpoints.  When disabled, the watchpoints are marked
    call_disabled.  When re-enabled, they are marked enabled.
 
diff --git a/gdb/btrace.c b/gdb/btrace.c
index 152f6f2ec47..4a056d20537 100644
--- a/gdb/btrace.c
+++ b/gdb/btrace.c
@@ -1531,23 +1531,23 @@  handle_pt_insn_events (struct btrace_thread_info *btinfo,
 
 	    if (event.variant.vmexit.has_vmxr != 0)
 	      {
-		std::string seperator = aux_string.back () == ':' ? "" : ",";
-		aux_string += seperator + std::string (" vmxr = ")
+		std::string separator = aux_string.back () == ':' ? "" : ",";
+		aux_string += separator + std::string (" vmxr = ")
 			      + hex_string (event.variant.vmexit.vmxr);
 	      }
 
 	    if (event.variant.vmexit.has_vmxq != 0)
 	      {
-		std::string seperator = aux_string.back () == ':' ? "" : ",";
-		aux_string += seperator + std::string (" vmxq = ")
+		std::string separator = aux_string.back () == ':' ? "" : ",";
+		aux_string += separator + std::string (" vmxq = ")
 			      + hex_string (event.variant.vmexit.vmxq);
 	      }
 
 	    if (event.ip_suppressed == 0)
 	      {
 		pc = event.variant.vmexit.ip;
-		std::string seperator = aux_string.back () == ':' ? "" : ",";
-		aux_string += seperator + std::string (" ip = ")
+		std::string separator = aux_string.back () == ':' ? "" : ",";
+		aux_string += separator + std::string (" ip = ")
 			      + hex_string (*pc);
 	      }
 
@@ -2136,7 +2136,7 @@  btrace_stitch_bts (struct btrace_data_bts *btrace, struct thread_info *tp)
 /* Adjust the block trace in order to stitch old and new trace together.
    BTRACE is the new delta trace between the last and the current stop.
    TP is the traced thread.
-   May modifx BTRACE as well as the existing trace in TP.
+   May modify BTRACE as well as the existing trace in TP.
    Return 0 on success, -1 otherwise.  */
 
 static int
diff --git a/gdb/buildsym.h b/gdb/buildsym.h
index 1d30f551ace..49e44a83161 100644
--- a/gdb/buildsym.h
+++ b/gdb/buildsym.h
@@ -55,7 +55,7 @@  struct subfile
   struct subfile *next = nullptr;
   std::string name;
 
-  /* This field is analoguous in function to symtab::filename_for_id.
+  /* This field is analogous in function to symtab::filename_for_id.
 
      It is used to look up existing subfiles in calls to start_subfile.  */
   std::string name_for_id;
diff --git a/gdb/coffread.c b/gdb/coffread.c
index c470668f6f6..e580f8c19c8 100644
--- a/gdb/coffread.c
+++ b/gdb/coffread.c
@@ -903,7 +903,7 @@  coff_symtab_read (minimal_symbol_reader &reader,
   symnum = 0;
   while (symnum < nsyms)
     {
-      QUIT;			/* Make this command interruptable.  */
+      QUIT;			/* Make this command interruptible.  */
 
       read_one_sym (cs, &main_sym, &main_aux);
 
diff --git a/gdb/command.h b/gdb/command.h
index 37c7ddf4725..7e6761d73b5 100644
--- a/gdb/command.h
+++ b/gdb/command.h
@@ -558,7 +558,7 @@  extern struct cmd_list_element *lookup_cmd (const char **,
    the section of text it matched, set *RESULT_LIST to point to the list in
    which the last word was matched, and will return a pointer to the cmd
    list element which the text matches.  It will return NULL if no match at
-   all was possible.  It will return -1 (cast appropriately, ick) if ambigous
+   all was possible.  It will return -1 (cast appropriately, ick) if ambiguous
    matches are possible; in this case *RESULT_LIST will be set to point to
    the list in which there are ambiguous choices (and *TEXT will be set to
    the ambiguous text string).
diff --git a/gdb/completer.c b/gdb/completer.c
index 4735aa5ed10..0a8409b4420 100644
--- a/gdb/completer.c
+++ b/gdb/completer.c
@@ -356,7 +356,7 @@  gdb_completer_file_name_quote_1 (const char *text, char quote_char)
   if (quote_char == '\'')
     {
       /* There is no backslash escaping permitted within a single quoted
-	 string, so in this case we can just return the input sting.  */
+	 string, so in this case we can just return the input string.  */
       str = text;
     }
   else if (quote_char == '"')
diff --git a/gdb/completer.h b/gdb/completer.h
index 07953f1e2ee..22d85a82070 100644
--- a/gdb/completer.h
+++ b/gdb/completer.h
@@ -722,7 +722,7 @@  extern void complete_nested_command_line (completion_tracker &tracker,
    This function is designed so that trying to complete '/' will offer no
    completions, the user needs to insert the format specification
    themselves.  Trying to complete '/FMT' (where FMT is any non-empty set
-   of alpha-numeric characters) will cause readline to insert a single
+   of alphanumeric characters) will cause readline to insert a single
    space, setting the user up to enter the expression.  */
 
 extern bool skip_over_slash_fmt (completion_tracker &tracker,
diff --git a/gdb/cp-namespace.c b/gdb/cp-namespace.c
index 370cb368450..46cefc68462 100644
--- a/gdb/cp-namespace.c
+++ b/gdb/cp-namespace.c
@@ -926,7 +926,7 @@  cp_lookup_nested_symbol (struct type *parent_type,
     case TYPE_CODE_NAMESPACE:
     case TYPE_CODE_UNION:
     case TYPE_CODE_ENUM:
-    /* NOTE: Handle modules here as well, because Fortran is re-using the C++
+    /* NOTE: Handle modules here as well, because Fortran is reusing the C++
        specific code to lookup nested symbols in modules, by calling the
        method lookup_symbol_nonlocal, which ends up here.  */
     case TYPE_CODE_MODULE:
diff --git a/gdb/cp-valprint.c b/gdb/cp-valprint.c
index 2634c1e33a6..2077fa3b915 100644
--- a/gdb/cp-valprint.c
+++ b/gdb/cp-valprint.c
@@ -100,7 +100,7 @@  cp_is_vtbl_member (struct type *type)
 	  /* The type name of the thunk pointer is NULL when using
 	     dwarf2.  We could test for a pointer to a function, but
 	     there is no type info for the virtual table either, so it
-	     wont help.  */
+	     won't help.  */
 	  return cp_is_vtbl_ptr_type (type);
 	}
     }
diff --git a/gdb/cris-tdep.c b/gdb/cris-tdep.c
index f531b4ce1f0..519ea43140b 100644
--- a/gdb/cris-tdep.c
+++ b/gdb/cris-tdep.c
@@ -1467,7 +1467,7 @@  cris_register_size (struct gdbarch *gdbarch, int regno)
 }
 
 /* Nonzero if regno should not be fetched from the target.  This is the case
-   for unimplemented (size 0) and non-existant registers.  */
+   for unimplemented (size 0) and non-existent registers.  */
 
 static int
 cris_cannot_fetch_register (struct gdbarch *gdbarch, int regno)
@@ -1508,7 +1508,7 @@  cris_cannot_store_register (struct gdbarch *gdbarch, int regno)
 }
 
 /* Nonzero if regno should not be fetched from the target.  This is the case
-   for unimplemented (size 0) and non-existant registers.  */
+   for unimplemented (size 0) and non-existent registers.  */
 
 static int
 crisv32_cannot_fetch_register (struct gdbarch *gdbarch, int regno)
diff --git a/gdb/csky-tdep.c b/gdb/csky-tdep.c
index 4f41a51b576..4f3d9d80b11 100644
--- a/gdb/csky-tdep.c
+++ b/gdb/csky-tdep.c
@@ -1072,7 +1072,7 @@  csky_analyze_prologue (struct gdbarch *gdbarch,
 	    }
 	  else if (CSKY_32_IS_MOV_FP_SP (insn))
 	    {
-	      /* SP is saved to FP reg, means code afer prologue may
+	      /* SP is saved to FP reg, means code after prologue may
 		 modify SP.  */
 	      is_fp_saved = 1;
 	      adjust_fp = stacksize;
@@ -2667,7 +2667,7 @@  csky_pseudo_register_write (struct gdbarch *gdbarch, struct regcache *regcache,
 }
 
 /* Initialize the current architecture based on INFO.  If possible,
-   re-use an architecture from ARCHES, which is a list of
+   reuse an architecture from ARCHES, which is a list of
    architectures already created during this debugging session.
 
    Called at program startup, when reading a core file, and when
diff --git a/gdb/displaced-stepping.h b/gdb/displaced-stepping.h
index 7949e5dae13..2806107dd4f 100644
--- a/gdb/displaced-stepping.h
+++ b/gdb/displaced-stepping.h
@@ -246,7 +246,7 @@  struct displaced_step_buffers
   std::vector<displaced_step_buffer> m_buffers;
 };
 
-/* Default implemention of target_ops::supports_displaced_step.
+/* Default implementation of target_ops::supports_displaced_step.
 
    Forwards the call to the architecture of THREAD.  */
 
diff --git a/gdb/dtrace-probe.c b/gdb/dtrace-probe.c
index ac1b1c5ef13..a5bc9d83d1a 100644
--- a/gdb/dtrace-probe.c
+++ b/gdb/dtrace-probe.c
@@ -424,7 +424,7 @@  dtrace_process_dof_probe (struct objfile *objfile,
 
      It follows that if there are DTrace is-enabled probes defined for
      some provider/name but no DTrace regular probes defined then the
-     GDB user wont be able to enable/disable these conditionals.  */
+     GDB user won't be able to enable/disable these conditionals.  */
 
   num_probes = DOF_UINT (dof, probe->dofpr_noffs);
   if (num_probes == 0)
diff --git a/gdb/elfread.c b/gdb/elfread.c
index 3756fa3bd33..ed664bca2f6 100644
--- a/gdb/elfread.c
+++ b/gdb/elfread.c
@@ -898,7 +898,7 @@  elf_gnu_ifunc_resolve_name (const char *name, CORE_ADDR *addr_p)
   return false;
 }
 
-/* Call STT_GNU_IFUNC - a function returning addresss of a real function to
+/* Call STT_GNU_IFUNC - a function returning address of a real function to
    call.  PC is theSTT_GNU_IFUNC resolving function entry.  The value returned
    is the entry point of the resolved STT_GNU_IFUNC target function to call.
    */
diff --git a/gdb/frame-base.h b/gdb/frame-base.h
index 8436929839e..ba12c709fa8 100644
--- a/gdb/frame-base.h
+++ b/gdb/frame-base.h
@@ -32,7 +32,7 @@  struct regcache;
    the NEXT frame's register unwind method, to determine the address
    of THIS frame's `base'.
 
-   The exact meaning of `base' is highly dependant on the type of the
+   The exact meaning of `base' is highly dependent on the type of the
    debug info.  It is assumed that dwarf2, stabs, ... will each
    provide their own methods.
 
diff --git a/gdb/frame.h b/gdb/frame.h
index e207c714c56..5dd0d168179 100644
--- a/gdb/frame.h
+++ b/gdb/frame.h
@@ -586,7 +586,7 @@  void set_current_sal_from_frame (const frame_info_ptr &);
    the old get_frame_base method was not sufficient.
 
    get_frame_base_address: get_frame_locals_address:
-   get_frame_args_address: A set of high-level debug-info dependant
+   get_frame_args_address: A set of high-level debug-info dependent
    addresses that fall within the frame.  These addresses almost
    certainly will not match the stack address part of a frame ID (as
    returned by get_frame_base).
diff --git a/gdb/ft32-tdep.c b/gdb/ft32-tdep.c
index 2ef77a271b4..8b8b6617c8f 100644
--- a/gdb/ft32-tdep.c
+++ b/gdb/ft32-tdep.c
@@ -310,7 +310,7 @@  ft32_skip_prologue (struct gdbarch *gdbarch, CORE_ADDR pc)
 		  return sal.end;
 		}
 	    }
-	  /* No useable line symbol.  Use result of prologue parsing method.  */
+	  /* No usable line symbol.  Use result of prologue parsing method.  */
 	  return plg_end;
 	}
     }
diff --git a/gdb/gdbarch.h b/gdb/gdbarch.h
index 786b720dfea..f179151d73d 100644
--- a/gdb/gdbarch.h
+++ b/gdb/gdbarch.h
@@ -210,7 +210,7 @@  gdbarch_tdep (struct gdbarch *gdbarch)
    information obtained from INFO.ABFD or the global defaults.
 
    The ARCHES parameter is a linked list (sorted most recently used)
-   of all the previously created architures for this architecture
+   of all the previously created architectures for this architecture
    family.  The (possibly NULL) ARCHES->gdbarch can used to access
    values from the previously selected architecture for this
    architecture family.
diff --git a/gdb/gdbthread.h b/gdb/gdbthread.h
index 6cffd86bc58..ff1cdc64010 100644
--- a/gdb/gdbthread.h
+++ b/gdb/gdbthread.h
@@ -70,10 +70,10 @@  extern bool debug_threads;
    you want.  */
 enum thread_state
 {
-  /* In the frontend's perpective, the thread is stopped.  */
+  /* In the frontend's perspective, the thread is stopped.  */
   THREAD_STOPPED,
 
-  /* In the frontend's perpective, the thread is running.  */
+  /* In the frontend's perspective, the thread is running.  */
   THREAD_RUNNING,
 
   /* The thread is listed, but known to have exited.  We keep it
diff --git a/gdb/gnu-v3-abi.c b/gdb/gnu-v3-abi.c
index b51c4d23fc7..70d66a569e2 100644
--- a/gdb/gnu-v3-abi.c
+++ b/gdb/gnu-v3-abi.c
@@ -1178,7 +1178,7 @@  gnuv3_get_type_from_type_info (struct value *type_info_ptr)
 {
   /* We have to parse the type name, since in general there is not a
      symbol for a type.  This is somewhat bogus since there may be a
-     mis-parse.  Another approach might be to re-use the demangler's
+     mis-parse.  Another approach might be to reuse the demangler's
      internal form to reconstruct the type somehow.  */
   std::string type_name = gnuv3_get_typename_from_type_info (type_info_ptr);
   expression_up expr (parse_expression (type_name.c_str ()));
diff --git a/gdb/h8300-tdep.c b/gdb/h8300-tdep.c
index a845900d299..6cffd0675f2 100644
--- a/gdb/h8300-tdep.c
+++ b/gdb/h8300-tdep.c
@@ -541,7 +541,7 @@  h8300_skip_prologue (struct gdbarch *gdbarch, CORE_ADDR pc)
 	/* Found a line number, use it as end of prologue.  */
 	return sal.end;
 
-      /* No useable line symbol.  Use prologue parsing method.  */
+      /* No usable line symbol.  Use prologue parsing method.  */
       h8300_init_frame_cache (gdbarch, &cache);
       return h8300_analyze_prologue (gdbarch, func_addr, func_end, &cache);
     }
diff --git a/gdb/hppa-linux-tdep.c b/gdb/hppa-linux-tdep.c
index f43a5e73856..f968f470380 100644
--- a/gdb/hppa-linux-tdep.c
+++ b/gdb/hppa-linux-tdep.c
@@ -322,7 +322,7 @@  static const struct frame_unwind_legacy hppa_linux_sigtramp_frame_unwind (
 /* Attempt to find (and return) the global pointer for the given
    function.
 
-   This is a rather nasty bit of code searchs for the .dynamic section
+   This is a rather nasty bit of code searches for the .dynamic section
    in the objfile corresponding to the pc of the function we're trying
    to call.  Once it finds the addresses at which the .dynamic section
    lives in the child process, it scans the Elf32_Dyn entries for a
diff --git a/gdb/i386-fbsd-nat.c b/gdb/i386-fbsd-nat.c
index d9f40677ca6..3b3ca4923e7 100644
--- a/gdb/i386-fbsd-nat.c
+++ b/gdb/i386-fbsd-nat.c
@@ -92,7 +92,7 @@  i386_fbsd_nat_target::fetch_registers (struct regcache *regcache, int regnum)
 
   /* There is no i386_fxsave_supplies or i386_xsave_supplies.
      Instead, the earlier register sets return early if the request
-     was for a specific register that was already satisified to avoid
+     was for a specific register that was already satisfied to avoid
      fetching the FPU/XSAVE state unnecessarily.  */
 
 #ifdef PT_GETXSTATE_INFO
@@ -171,7 +171,7 @@  i386_fbsd_nat_target::store_registers (struct regcache *regcache, int regnum)
 
   /* There is no i386_fxsave_supplies or i386_xsave_supplies.
      Instead, the earlier register sets return early if the request
-     was for a specific register that was already satisified to avoid
+     was for a specific register that was already satisfied to avoid
      fetching the FPU/XSAVE state unnecessarily.  */
 
 #ifdef PT_GETXSTATE_INFO
diff --git a/gdb/i386-sol2-nat.c b/gdb/i386-sol2-nat.c
index 20ca9d68cbc..665756a012b 100644
--- a/gdb/i386-sol2-nat.c
+++ b/gdb/i386-sol2-nat.c
@@ -25,7 +25,7 @@ 
 #include "target.h"
 #include "procfs.h"
 
-/* This file provids the (temporary) glue between the Solaris x86
+/* This file provides the (temporary) glue between the Solaris x86
    target dependent code and the machine independent SVR4 /proc
    support.  */
 
diff --git a/gdb/i386-tdep.c b/gdb/i386-tdep.c
index 1d6d5925de4..f14a0d396a6 100644
--- a/gdb/i386-tdep.c
+++ b/gdb/i386-tdep.c
@@ -2322,7 +2322,7 @@  static const struct frame_unwind_legacy i386_epilogue_frame_unwind (
 /* These trampolines are used on cross x86 targets, when taking the
    address of a nested function.  When executing these trampolines,
    no stack frame is set up, so we are in a similar situation as in
-   epilogues and i386_epilogue_frame_this_id can be re-used.  */
+   epilogues and i386_epilogue_frame_this_id can be reused.  */
 
 /* Static chain passed in register.  */
 
@@ -5015,7 +5015,7 @@  i386_record_vex (struct i386_record_s *ir, uint8_t vex_w, uint8_t vex_r,
     case 0x5e:	/* VDIV[P|S][S|D]  */
     case 0x5f:	/* VMAX[P|S][S|D]  */
       {
-	/* vpbroadcast and arithmethic operations are differentiated
+	/* vpbroadcast and arithmetic operations are differentiated
 	   by map_select, but it doesn't change the recording mechanics.  */
 	i386_record_modrm (ir);
 	int reg_offset = ir->reg + vex_r * 8;
diff --git a/gdb/ia64-tdep.c b/gdb/ia64-tdep.c
index 11375d5bc69..62883555aa9 100644
--- a/gdb/ia64-tdep.c
+++ b/gdb/ia64-tdep.c
@@ -596,7 +596,7 @@  fetch_instruction (CORE_ADDR addr, ia64_instruction_type *it, long long *instr)
    If we would like to store the whole bundle to SHADOW_CONTENTS we would have
    to store already the base address (`address & ~0x0f') into PLACED_ADDRESS.
    In such case there is no other place where to store
-   SLOTNUM (`adress & 0x0f', value in the range <0..2>).  We need to know
+   SLOTNUM (`address & 0x0f', value in the range <0..2>).  We need to know
    SLOTNUM in ia64_memory_remove_breakpoint.
 
    There is one special case where we need to be extra careful:
@@ -3111,7 +3111,7 @@  static const struct frame_unwind_legacy ia64_libunwind_sigtramp_frame_unwind (
   ia64_libunwind_sigtramp_frame_sniffer
 );
 
-/* Set of libunwind callback acccessor functions.  */
+/* Set of libunwind callback accessor functions.  */
 unw_accessors_t ia64_unw_accessors =
 {
   ia64_find_proc_info_x,
@@ -3124,7 +3124,7 @@  unw_accessors_t ia64_unw_accessors =
   /* get_proc_name */
 };
 
-/* Set of special libunwind callback acccessor functions specific for accessing
+/* Set of special libunwind callback accessor functions specific for accessing
    the rse registers.  At the top of the stack, we want libunwind to figure out
    how to read r32 - r127.  Though usually they are found sequentially in
    memory starting from $bof, this is not always true.  */
@@ -3415,7 +3415,7 @@  slot_alignment_is_next_even (struct type *t)
 /* Attempt to find (and return) the global pointer for the given
    function.
 
-   This is a rather nasty bit of code searchs for the .dynamic section
+   This is a rather nasty bit of code searches for the .dynamic section
    in the objfile corresponding to the pc of the function we're trying
    to call.  Once it finds the addresses at which the .dynamic section
    lives in the child process, it scans the Elf64_Dyn entries for a
diff --git a/gdb/ia64-vms-tdep.c b/gdb/ia64-vms-tdep.c
index 20308c70720..ef8f42d1ad9 100644
--- a/gdb/ia64-vms-tdep.c
+++ b/gdb/ia64-vms-tdep.c
@@ -118,7 +118,7 @@  ia64_vms_get_dyn_info_list (unw_addr_space_t as,
   return -UNW_ENOINFO;
 }
 
-/* Set of libunwind callback acccessor functions.  */
+/* Set of libunwind callback accessor functions.  */
 static unw_accessors_t ia64_vms_unw_accessors;
 static unw_accessors_t ia64_vms_unw_rse_accessors;
 
diff --git a/gdb/inf-loop.c b/gdb/inf-loop.c
index ec0c059729e..565accae9e6 100644
--- a/gdb/inf-loop.c
+++ b/gdb/inf-loop.c
@@ -74,7 +74,7 @@  inferior_event_handler (enum inferior_event_type event_type)
 	    {
 	      /* If the user was running a foreground execution
 		 command, then propagate the error so that the prompt
-		 can be reenabled.  Otherwise, the user already has
+		 can be re-enabled.  Otherwise, the user already has
 		 the prompt and is typing some unrelated command, so
 		 just inform the user and swallow the exception.  */
 	      if (current_ui->prompt_state == PROMPT_BLOCKED)
diff --git a/gdb/infcall.c b/gdb/infcall.c
index 6399278c6ae..af3ad0a5d57 100644
--- a/gdb/infcall.c
+++ b/gdb/infcall.c
@@ -1276,7 +1276,7 @@  call_function_by_hand_dummy (struct value *function,
 	/* A call dummy always consists of just a single breakpoint, so
 	   its address is the same as the address of the dummy.
 
-	   The actual breakpoint is inserted separatly so there is no need to
+	   The actual breakpoint is inserted separately so there is no need to
 	   write that out.  */
 	bp_addr = dummy_addr;
 	break;
diff --git a/gdb/infrun.c b/gdb/infrun.c
index 9f5b3d473f8..e03942d9275 100644
--- a/gdb/infrun.c
+++ b/gdb/infrun.c
@@ -9444,7 +9444,7 @@  struct stop_context
 
   ptid_t ptid;
 
-  /* If stopp for a thread event, this is the thread that caused the
+  /* If stopped for a thread event, this is the thread that caused the
      stop.  */
   thread_info_ref thread;
 
diff --git a/gdb/iq2000-tdep.c b/gdb/iq2000-tdep.c
index 094f627e37b..6ec37fcaeaf 100644
--- a/gdb/iq2000-tdep.c
+++ b/gdb/iq2000-tdep.c
@@ -348,7 +348,7 @@  iq2000_skip_prologue (struct gdbarch *gdbarch, CORE_ADDR pc)
 	/* Found a line number, use it as end of prologue.  */
 	return sal.end;
 
-      /* No useable line symbol.  Use prologue parsing method.  */
+      /* No usable line symbol.  Use prologue parsing method.  */
       iq2000_init_frame_cache (&cache);
       return iq2000_scan_prologue (gdbarch, func_addr, func_end, NULL, &cache);
     }
diff --git a/gdb/linux-nat.c b/gdb/linux-nat.c
index 1727a06d51d..e58fd664d96 100644
--- a/gdb/linux-nat.c
+++ b/gdb/linux-nat.c
@@ -133,7 +133,7 @@  process things as in sync mode, except that the we never block in
 sigsuspend.
 
 While processing an event, we may end up momentarily blocked in
-waitpid calls.  Those waitpid calls, while blocking, are guarantied to
+waitpid calls.  Those waitpid calls, while blocking, are guaranteed to
 return quickly.  E.g., in all-stop mode, before reporting to the core
 that an LWP hit a breakpoint, all LWPs are stopped by sending them
 SIGSTOP, and synchronously waiting for the SIGSTOP to be reported.
@@ -702,7 +702,7 @@  lwp_lwpid_htab_add_lwp (struct lwp_info *lp)
 
 /* Head of doubly-linked list of known LWPs.  Sorted by reverse
    creation order.  This order is assumed in some cases.  E.g.,
-   reaping status after killing alls lwps of a process: the leader LWP
+   reaping status after killing all lwps of a process: the leader LWP
    must be reaped last.  */
 
 static intrusive_list<lwp_info> lwp_list;
diff --git a/gdb/linux-tdep.c b/gdb/linux-tdep.c
index fec6a6343d7..852fea7e3d9 100644
--- a/gdb/linux-tdep.c
+++ b/gdb/linux-tdep.c
@@ -1073,7 +1073,7 @@  linux_info_proc (struct gdbarch *gdbarch, const char *args,
 	    gdb_printf (_("Ignored signals bitmap: %s\n"),
 			hex_string (strtoulst (p, &p, 10)));
 	  if (*p)
-	    gdb_printf (_("Catched signals bitmap: %s\n"),
+	    gdb_printf (_("Caught signals bitmap: %s\n"),
 			hex_string (strtoulst (p, &p, 10)));
 	  if (*p)
 	    gdb_printf (_("wchan (system call): %s\n"),
@@ -2749,7 +2749,7 @@  linux_vsyscall_range_raw (struct gdbarch *gdbarch, struct mem_range *range)
      in the output, which requires scanning every thread in the thread
      group to check whether a VMA is actually a thread's stack.  With
      Linux 4.4 on an Intel i7-4810MQ @ 2.80GHz, with an inferior with
-     a few thousand threads, (1) takes a few miliseconds, while (2)
+     a few thousand threads, (1) takes a few milliseconds, while (2)
      takes several seconds.  Also note that "smaps", what we read for
      determining core dump mappings, is even slower than "maps".  */
   xsnprintf (filename, sizeof filename, "/proc/%ld/task/%ld/maps", pid, pid);
diff --git a/gdb/loongarch-linux-tdep.c b/gdb/loongarch-linux-tdep.c
index 031031b84ba..14d18875ecb 100644
--- a/gdb/loongarch-linux-tdep.c
+++ b/gdb/loongarch-linux-tdep.c
@@ -938,7 +938,7 @@  loongarch_record_all_but_pc_registers (struct regcache *regcache)
   return 0;
 }
 
-/* Handler for LoongArch architechture system call instruction recording.  */
+/* Handler for LoongArch architecture system call instruction recording.  */
 
 static int
 loongarch_linux_syscall_record (struct regcache *regcache,
diff --git a/gdb/machoread.c b/gdb/machoread.c
index ac764c09496..a9b1bea231a 100644
--- a/gdb/machoread.c
+++ b/gdb/machoread.c
@@ -164,7 +164,7 @@  macho_symtab_read (minimal_symbol_reader &reader,
     S_NO_SO,
 
     /* First SO read.  Introduce an SO section, and may be followed by a second
-       SO.  The SO section should contain onl debugging symbols.  */
+       SO.  The SO section should contain only debugging symbols.  */
     S_FIRST_SO,
 
     /* Second non-null SO found, just after the first one.  Means that the first
diff --git a/gdb/main.c b/gdb/main.c
index b173eb6b4cb..ca34bf1499f 100644
--- a/gdb/main.c
+++ b/gdb/main.c
@@ -1124,7 +1124,7 @@  captured_main_1 (struct captured_main_args *context)
 
   /* Do these (and anything which might call wrap_here or *_filtered)
      after initialize_all_files() but before the interpreter has been
-     installed.  Otherwize the help/version messages will be eaten by
+     installed.  Otherwise the help/version messages will be eaten by
      the interpreter's output handler.  */
 
   if (print_version)
diff --git a/gdb/mdebugread.c b/gdb/mdebugread.c
index d5a07406ecb..cdfac15e289 100644
--- a/gdb/mdebugread.c
+++ b/gdb/mdebugread.c
@@ -1119,7 +1119,7 @@  parse_symbol (SYMR *sh, union aux_ext *ax, char *ext_sh, int bigend,
 
     case_stBlock_code:
       found_ecoff_debugging_info = 1;
-      /* Beginnning of (code) block.  Value of symbol
+      /* Beginning of (code) block.  Value of symbol
 	 is the displacement from procedure start.  */
       push_parse_stack ();
 
@@ -2122,7 +2122,7 @@  parse_external (EXTR *es, int bigend, const section_offsets &section_offsets,
       /* There is no need to parse the external procedure symbols.
 	 If they are from objects compiled without -g, their index will
 	 be indexNil, and the symbol definition from the minimal symbol
-	 is preferrable (yielding a function returning int instead of int).
+	 is preferable (yielding a function returning int instead of int).
 	 If the index points to a local procedure symbol, the local
 	 symbol already provides the correct type.
 	 Note that the index of the external procedure symbol points
@@ -2488,7 +2488,7 @@  parse_partial_symbols (minimal_symbol_reader &reader,
       switch (ext_in->asym.st)
 	{
 	case stProc:
-	  /* Beginnning of Procedure */
+	  /* Beginning of Procedure */
 	  break;
 	case stStaticProc:
 	  /* Load time only static procs */
@@ -2938,7 +2938,7 @@  parse_partial_symbols (minimal_symbol_reader &reader,
 						   name SOs.  */
 
 		      /* Some other compilers (C++ ones in particular) emit
-			 useless SOs for non-existant .c files.  We ignore
+			 useless SOs for non-existent .c files.  We ignore
 			 all subsequent SOs that immediately follow the
 			 first.  */
 
diff --git a/gdb/mips-tdep.c b/gdb/mips-tdep.c
index 3613f9bec8d..331ef702124 100644
--- a/gdb/mips-tdep.c
+++ b/gdb/mips-tdep.c
@@ -7027,7 +7027,7 @@  gdb_print_insn_mips (bfd_vma memaddr, struct disassemble_info *info)
 
   /* FIXME: cagney/2003-06-26: Is this even necessary?  The
      disassembler needs to be able to locally determine the ISA, and
-     not rely on GDB.  Otherwize the stand-alone 'objdump -d' will not
+     not rely on GDB.  Otherwise the stand-alone 'objdump -d' will not
      work.  */
   if (mips_pc_is_mips16 (gdbarch, memaddr))
     info->mach = bfd_mach_mips16;
diff --git a/gdb/moxie-tdep.c b/gdb/moxie-tdep.c
index f69810f83c3..47c78c031e3 100644
--- a/gdb/moxie-tdep.c
+++ b/gdb/moxie-tdep.c
@@ -240,7 +240,7 @@  moxie_skip_prologue (struct gdbarch *gdbarch, CORE_ADDR pc)
 		  return sal.end;
 		}
 	    }
-	  /* No useable line symbol.  Use result of prologue parsing
+	  /* No useble line symbol.  Use result of prologue parsing
 	     method.  */
 	  return plg_end;
 	}
diff --git a/gdb/nds32-tdep.c b/gdb/nds32-tdep.c
index e08ead24b4f..ed4e46071ec 100644
--- a/gdb/nds32-tdep.c
+++ b/gdb/nds32-tdep.c
@@ -1935,7 +1935,7 @@  nds32_validate_tdesc_p (const struct target_desc *tdesc,
 }
 
 /* Initialize the current architecture based on INFO.  If possible,
-   re-use an architecture from ARCHES, which is a list of
+   reuse an architecture from ARCHES, which is a list of
    architectures already created during this debugging session.
 
    Called e.g. at program startup, when reading a core file, and when
diff --git a/gdb/p-exp.y b/gdb/p-exp.y
index 938d3cf2024..1128f245312 100644
--- a/gdb/p-exp.y
+++ b/gdb/p-exp.y
@@ -765,7 +765,7 @@  typebase  /* Implements (approximately): (type-qualifier)* type-specifier */
 			    = lookup_struct (copy_name ($2).c_str (),
 					     pstate->expression_context_block);
 			}
-	/* "const" and "volatile" are curently ignored.  A type qualifier
+	/* "const" and "volatile" are currently ignored.  A type qualifier
 	   after the type is handled in the ptype rule.  I think these could
 	   be too.  */
 	;
diff --git a/gdb/record-full.c b/gdb/record-full.c
index 6d056514e8b..09f0e949a47 100644
--- a/gdb/record-full.c
+++ b/gdb/record-full.c
@@ -1647,7 +1647,7 @@  record_full_target::store_registers (struct regcache *regcache, int regno)
 
 /* "xfer_partial" method.  Behavior is conditional on
    RECORD_FULL_IS_REPLAY.
-   In replay mode, we cannot write memory unles we are willing to
+   In replay mode, we cannot write memory unless we are willing to
    invalidate the record/replay log from this point forward.  */
 
 enum target_xfer_status
@@ -2368,7 +2368,7 @@  record_full_restore (void)
   bfdcore_read (current_program_space->core_bfd (), osec, &magic,
 		sizeof (magic), &bfd_offset);
   if (magic != RECORD_FULL_FILE_MAGIC)
-    error (_("Version mis-match or file format error in core file %s."),
+    error (_("Version mismatch or file format error in core file %s."),
 	   bfd_get_filename (current_program_space->core_bfd ()));
   if (record_debug)
     gdb_printf (gdb_stdlog,
diff --git a/gdb/remote.c b/gdb/remote.c
index 66c58c884d3..8456750311b 100644
--- a/gdb/remote.c
+++ b/gdb/remote.c
@@ -9035,7 +9035,7 @@  remote_target::process_g_packet (struct regcache *regcache)
 
   /* Reply describes registers byte by byte, each byte encoded as two
      hex characters.  Suck them all up, then supply them to the
-     register cacheing/storage mechanism.  */
+     register caching/storage mechanism.  */
 
   p = rs->buf.data ();
   for (i = 0; i < rsa->sizeof_g_packet; i++)
diff --git a/gdb/riscv-tdep.c b/gdb/riscv-tdep.c
index 6eeb1c11d78..4c18f14bca4 100644
--- a/gdb/riscv-tdep.c
+++ b/gdb/riscv-tdep.c
@@ -4188,7 +4188,7 @@  static const char *const stap_register_indirection_suffixes[] =
 };
 
 /* Initialize the current architecture based on INFO.  If possible,
-   re-use an architecture from ARCHES, which is a list of
+   reuse an architecture from ARCHES, which is a list of
    architectures already created during this debugging session.
 
    Called e.g. at program startup, when reading a core file, and when
diff --git a/gdb/rs6000-tdep.c b/gdb/rs6000-tdep.c
index 0d1c89bc411..5fdabeb9141 100644
--- a/gdb/rs6000-tdep.c
+++ b/gdb/rs6000-tdep.c
@@ -6951,7 +6951,7 @@  ppc_process_record_prefix_store_vsx_ds_form (struct gdbarch *gdbarch,
 }
 
 /* Record the prefixed VSX, form D, instructions.  The arguments are the
-   instruction address for PC-relative addresss (addr), the first 32-bits of
+   instruction address for PC-relative address (addr), the first 32-bits of
    the instruction (insn_prefix) and the following 32-bits of the instruction
    (insn_suffix).  Return 0 on success.  */
 
@@ -7583,7 +7583,7 @@  ppc64_update_call_site_pc (struct gdbarch *gdbarch, CORE_ADDR pc)
   return pc + 4;
 }
 
-/* Initialize the current architecture based on INFO.  If possible, re-use an
+/* Initialize the current architecture based on INFO.  If possible, reuse an
    architecture from ARCHES, which is a list of architectures already created
    during this debugging session.
 
diff --git a/gdb/run-on-main-thread.c b/gdb/run-on-main-thread.c
index 746ea35ee9e..50efe076e1e 100644
--- a/gdb/run-on-main-thread.c
+++ b/gdb/run-on-main-thread.c
@@ -83,7 +83,7 @@  run_events (int error, gdb_client_data client_data)
 	}
       catch (const gdb_exception_quit &e)
 	{
-	  /* Should cancelation of a runnable event cancel the execution of
+	  /* Should cancellation of a runnable event cancel the execution of
 	     the following one?  The answer is not clear, so keep doing what
 	     we've done so far: ignore this exception.  */
 	}
diff --git a/gdb/s390-tdep.c b/gdb/s390-tdep.c
index 41faf93c423..bb204fe24ef 100644
--- a/gdb/s390-tdep.c
+++ b/gdb/s390-tdep.c
@@ -2488,7 +2488,7 @@  s390_prologue_frame_unwind_cache (const frame_info_ptr &this_frame,
 	 size zero.  This is only possible if the next frame is a sentinel
 	 frame, a dummy frame, or a signal trampoline frame.  */
       /* FIXME: cagney/2004-05-01: This sanity check shouldn't be
-	 needed, instead the code should simpliy rely on its
+	 needed, instead the code should simply rely on its
 	 analysis.  */
       next_frame = get_next_frame (this_frame);
       while (next_frame && get_frame_type (next_frame) == INLINE_FRAME)
@@ -2537,7 +2537,7 @@  s390_prologue_frame_unwind_cache (const frame_info_ptr &this_frame,
      code at a point where the frame pointer has already been restored.
      This can only happen in an innermost frame.  */
   /* FIXME: cagney/2004-05-01: This sanity check shouldn't be needed,
-     instead the code should simpliy rely on its analysis.  */
+     instead the code should simply rely on its analysis.  */
   next_frame = get_next_frame (this_frame);
   while (next_frame && get_frame_type (next_frame) == INLINE_FRAME)
     next_frame = get_next_frame (next_frame);
diff --git a/gdb/ser-mingw.c b/gdb/ser-mingw.c
index 2603bb8dcfb..a1a59ee3c55 100644
--- a/gdb/ser-mingw.c
+++ b/gdb/ser-mingw.c
@@ -281,10 +281,10 @@  ser_windows_wait_handle (struct serial *scb, HANDLE *read, HANDLE *except)
      cleared, and we get a duplicated event, if the last batch
      of characters included at least two arriving close together.  */
   if (!SetCommMask (h, 0))
-    warning (_("ser_windows_wait_handle: reseting mask failed"));
+    warning (_("ser_windows_wait_handle: resetting mask failed"));
 
   if (!SetCommMask (h, EV_RXCHAR))
-    warning (_("ser_windows_wait_handle: reseting mask failed (2)"));
+    warning (_("ser_windows_wait_handle: resetting mask failed (2)"));
 
   /* There's a potential race condition here; we must check cbInQue
      and not wait if that's nonzero.  */
diff --git a/gdb/ser-unix.c b/gdb/ser-unix.c
index 02845aa938b..19133097d7f 100644
--- a/gdb/ser-unix.c
+++ b/gdb/ser-unix.c
@@ -404,7 +404,7 @@  rate_to_code (int rate)
 
   for (i = 0; baudtab[i].rate != -1; i++)
     {
-      /* test for perfect macth.  */
+      /* test for perfect match.  */
       if (rate == baudtab[i].rate)
 	return baudtab[i].code;
       else
diff --git a/gdb/solib-rocm.c b/gdb/solib-rocm.c
index 156b36a4263..b49f529cd72 100644
--- a/gdb/solib-rocm.c
+++ b/gdb/solib-rocm.c
@@ -403,7 +403,7 @@  struct rocm_code_object_stream_memory final : public rocm_code_object_stream
 
   /* Snapshot of the original ELF image taken during load.  This is done to
      support the situation where an inferior uses an in-memory image, and
-     releases or re-uses this memory before GDB is done using it.  */
+     releases or reuses this memory before GDB is done using it.  */
   gdb::byte_vector m_objfile_image;
 
   LONGEST size () override
diff --git a/gdb/solib.c b/gdb/solib.c
index 0bbcb023c06..1d26970fab1 100644
--- a/gdb/solib.c
+++ b/gdb/solib.c
@@ -68,7 +68,7 @@  show_solib_search_path (struct ui_file *file, int from_tty,
 	      value);
 }
 
-/* Same as HAVE_DOS_BASED_FILE_SYSTEM, but useable as an rvalue.  */
+/* Same as HAVE_DOS_BASED_FILE_SYSTEM, but usable as an rvalue.  */
 #if (HAVE_DOS_BASED_FILE_SYSTEM)
 #define DOS_BASED_FILE_SYSTEM 1
 #else
diff --git a/gdb/sparc-obsd-tdep.c b/gdb/sparc-obsd-tdep.c
index 2bc944efca0..8329f3af324 100644
--- a/gdb/sparc-obsd-tdep.c
+++ b/gdb/sparc-obsd-tdep.c
@@ -147,7 +147,7 @@  static const struct frame_unwind_legacy sparc32obsd_sigtramp_frame_unwind (
 
 
 
-/* Offset wthin the thread structure where we can find %fp and %i7.  */
+/* Offset within the thread structure where we can find %fp and %i7.  */
 #define SPARC32OBSD_UTHREAD_FP_OFFSET	128
 #define SPARC32OBSD_UTHREAD_PC_OFFSET	132
 
diff --git a/gdb/sparc-sol2-nat.c b/gdb/sparc-sol2-nat.c
index 8f9607f338d..8d046968830 100644
--- a/gdb/sparc-sol2-nat.c
+++ b/gdb/sparc-sol2-nat.c
@@ -26,7 +26,7 @@ 
 #include "target.h"
 #include "procfs.h"
 
-/* This file provids the (temporary) glue between the Solaris SPARC
+/* This file provides the (temporary) glue between the Solaris SPARC
    target dependent code and the machine independent SVR4 /proc
    support.  */
 
diff --git a/gdb/sparc64-obsd-tdep.c b/gdb/sparc64-obsd-tdep.c
index 8596d2fa069..175ccb5064f 100644
--- a/gdb/sparc64-obsd-tdep.c
+++ b/gdb/sparc64-obsd-tdep.c
@@ -318,7 +318,7 @@  static const struct frame_unwind_legacy sparc64obsd_trapframe_unwind (
 
 /* Threads support.  */
 
-/* Offset wthin the thread structure where we can find %fp and %i7.  */
+/* Offset within the thread structure where we can find %fp and %i7.  */
 #define SPARC64OBSD_UTHREAD_FP_OFFSET	232
 #define SPARC64OBSD_UTHREAD_PC_OFFSET	240
 
diff --git a/gdb/stabsread.c b/gdb/stabsread.c
index fcc226ebd1f..73f50fe6b0c 100644
--- a/gdb/stabsread.c
+++ b/gdb/stabsread.c
@@ -891,7 +891,7 @@  read_ofile_symtab (struct objfile *objfile, legacy_psymtab *pst)
        symnum < max_symnum;
        symnum++)
     {
-      QUIT;			/* Allow this to be interruptable.  */
+      QUIT;			/* Allow this to be interruptible.  */
       if (symbuf_idx == symbuf_end)
 	fill_symbuf (abfd, objfile);
       bufp = &symbuf[symbuf_idx++];
@@ -1301,7 +1301,7 @@  read_stabs_symtab_1 (minimal_symbol_reader &reader,
   for (symnum = 0; symnum < DBX_SYMCOUNT (objfile); symnum++)
     {
       /* Get the symbol for this run and pull out some info.  */
-      QUIT;			/* Allow this to be interruptable.  */
+      QUIT;			/* Allow this to be interruptible.  */
       if (symbuf_idx == symbuf_end)
 	fill_symbuf (abfd, objfile);
       bufp = &symbuf[symbuf_idx++];
@@ -1540,7 +1540,7 @@  read_stabs_symtab_1 (minimal_symbol_reader &reader,
 	      }
 
 	    /* Some other compilers (C++ ones in particular) emit useless
-	       SOs for non-existant .c files.  We ignore all subsequent SOs
+	       SOs for non-existent .c files.  We ignore all subsequent SOs
 	       that immediately follow the first.  */
 
 	    if (!pst)
@@ -3511,7 +3511,7 @@  define_symbol (CORE_ADDR valu, const char *string, int desc, int type,
       sym->set_aclass_index (LOC_STATIC);
       sym->set_domain (VAR_DOMAIN);
       /* Don't add symbol references to global_sym_chain.
-	 Symbol references don't have valid names and wont't match up with
+	 Symbol references don't have valid names and won't match up with
 	 minimal symbols when the global_sym_chain is relocated.
 	 We'll fixup symbol references when we fixup the defining symbol.  */
       if (sym->linkage_name () && sym->linkage_name ()[0] != '#')
@@ -4907,7 +4907,7 @@  read_member_functions (struct stab_field_info *fip, const char **pp,
 		int nbits;
 		/* virtual member function, followed by index.
 		   The sign bit is set to distinguish pointers-to-methods
-		   from virtual function indicies.  Since the array is
+		   from virtual function indices.  Since the array is
 		   in words, the quantity must be shifted left by 1
 		   on 16 bit machine, and by 2 on 32 bit machine, forcing
 		   the sign bit out, and usable as a valid index into
diff --git a/gdb/stabsread.h b/gdb/stabsread.h
index 273ceaa7531..99ca215b2c5 100644
--- a/gdb/stabsread.h
+++ b/gdb/stabsread.h
@@ -131,7 +131,7 @@  struct header_file
 /* The actual length of HEADER_FILES.  */
 #define N_HEADER_FILES(OBJFILE) (DBX_SYMFILE_INFO (OBJFILE)->n_header_files)
 
-/* The allocated lengh of HEADER_FILES.  */
+/* The allocated length of HEADER_FILES.  */
 #define N_ALLOCATED_HEADER_FILES(OBJFILE) \
   (DBX_SYMFILE_INFO (OBJFILE)->n_allocated_header_files)
 
diff --git a/gdb/stack.c b/gdb/stack.c
index 6f986aa8297..6c4e0cd9320 100644
--- a/gdb/stack.c
+++ b/gdb/stack.c
@@ -827,7 +827,7 @@  print_frame_args (const frame_print_options &fp_opts,
 		     (1) Because find_saved_registers may be slow for
 			 remote debugging.
 
-		     (2) Because registers are often re-used and stack
+		     (2) Because registers are often reused and stack
 			 slots rarely (never?) are.  Therefore using
 			 the stack slot is much less likely to print
 			 garbage.
diff --git a/gdb/stap-probe.c b/gdb/stap-probe.c
index b312b38db04..fc37a59fb60 100644
--- a/gdb/stap-probe.c
+++ b/gdb/stap-probe.c
@@ -1225,7 +1225,7 @@  stap_parse_argument (const char **arg, struct type *atype,
 {
   /* We need to initialize the expression buffer, in order to begin
      our parsing efforts.  We use language_c here because we may need
-     to do pointer arithmetics.  */
+     to do pointer arithmetic.  */
   struct stap_parse_info p (*arg, atype, language_def (language_c),
 			    gdbarch);
 
diff --git a/gdb/symfile.c b/gdb/symfile.c
index b0c178a5aeb..6c3af619f7b 100644
--- a/gdb/symfile.c
+++ b/gdb/symfile.c
@@ -3035,7 +3035,7 @@  section_is_mapped (struct obj_section *osect)
     case ovly_off:
       return 0;			/* overlay debugging off */
     case ovly_auto:		/* overlay debugging automatic */
-      /* Unles there is a gdbarch_overlay_update function,
+      /* Unless there is a gdbarch_overlay_update function,
 	 there's really nothing useful to do here (can't really go auto).  */
       gdbarch = osect->objfile->arch ();
       if (gdbarch_overlay_update_p (gdbarch))
diff --git a/gdb/symtab.c b/gdb/symtab.c
index 06e2cd5b877..3ab1a58da18 100644
--- a/gdb/symtab.c
+++ b/gdb/symtab.c
@@ -6550,7 +6550,7 @@  find_main_name (void)
      language.  It is easy to guaranty this with Ada, since we use a
      special symbol generated only when the main in Ada to find the name
      of the main procedure.  It is difficult however to see how this can
-     be guarantied for languages such as C, for instance.  This suggests
+     be guaranteed for languages such as C, for instance.  This suggests
      that order of call for these methods becomes important, which means
      a more complicated approach.  */
   new_main_name = ada_main_name ();
diff --git a/gdb/top.c b/gdb/top.c
index b2575bc2b58..80d0ec5e679 100644
--- a/gdb/top.c
+++ b/gdb/top.c
@@ -381,7 +381,7 @@  check_frame_language_change (void)
   /* Warn the user if the working language does not match the language
      of the current frame.  Only warn the user if we are actually
      running the program, i.e. there is a stack.  */
-  /* FIXME: This should be cacheing the frame and only running when
+  /* FIXME: This should be caching the frame and only running when
      the frame changes.  */
 
   if (warn_frame_lang_mismatch && has_stack_frames ())
diff --git a/gdb/utils.c b/gdb/utils.c
index ee7cf4d2901..2244b90ebd6 100644
--- a/gdb/utils.c
+++ b/gdb/utils.c
@@ -382,7 +382,7 @@  internal_vproblem (struct internal_problem *problem,
 #endif
 
   /* Create a string containing the full error/warning message.  Need
-     to call query with this full string, as otherwize the reason
+     to call query with this full string, as otherwise the reason
      (error/warning) and question become separated.  Format using a
      style similar to a compiler error message.  Include extra detail
      so that the user knows that they are living on the edge.  */
diff --git a/gdb/value.c b/gdb/value.c
index ddc0959c224..d4548b87674 100644
--- a/gdb/value.c
+++ b/gdb/value.c
@@ -107,7 +107,7 @@  ranges_contain (const std::vector<range> &ranges, LONGEST offset,
      range, we can do a binary search for the position the given range
      would be inserted if we only considered the starting OFFSET of
      ranges.  We call that position I.  Since we also have LENGTH to
-     care for (this is a range afterall), we need to check if the
+     care for (this is a range after all), we need to check if the
      _previous_ range overlaps the I range.  E.g.,
 
 	 R
@@ -267,7 +267,7 @@  insert_into_bit_range_vector (std::vector<range> *vectorp,
   /* Do a binary search for the position the given range would be
      inserted if we only considered the starting OFFSET of ranges.
      Call that position I.  Since we also have LENGTH to care for
-     (this is a range afterall), we need to check if the _previous_
+     (this is a range after all), we need to check if the _previous_
      range overlaps the I range.  E.g., calling R the new range:
 
        #1 - overlaps with previous
@@ -2833,7 +2833,7 @@  value_as_address (struct value *val)
 #endif
 }
 
-/* Unpack raw data (copied from debugee, target byte order) at VALADDR
+/* Unpack raw data (copied from debuggee, target byte order) at VALADDR
    as a long, or as a double, assuming the raw data is described
    by type TYPE.  Knows how to convert different sizes of values
    and can convert between fixed and floating point.  We don't assume
@@ -2924,7 +2924,7 @@  unpack_long (struct type *type, const gdb_byte *valaddr)
     }
 }
 
-/* Unpack raw data (copied from debugee, target byte order) at VALADDR
+/* Unpack raw data (copied from debuggee, target byte order) at VALADDR
    as a CORE_ADDR, assuming the raw data is described by type TYPE.
    We don't assume any alignment for the raw data.  Return value is in
    host byte order.
diff --git a/gdb/value.h b/gdb/value.h
index 8e5fd5403cc..bb6005b432e 100644
--- a/gdb/value.h
+++ b/gdb/value.h
@@ -961,7 +961,7 @@  struct lval_funcs
      This may simply return the same closure, if VALUE's is
      reference-counted or statically allocated.
 
-     This may be NULL, in which case VALUE's closure is re-used in the
+     This may be NULL, in which case VALUE's closure is reused in the
      new value.  */
   void *(*copy_closure) (const struct value *v);
 
diff --git a/gdb/varobj.c b/gdb/varobj.c
index dcadce1b97a..cf27b1e5979 100644
--- a/gdb/varobj.c
+++ b/gdb/varobj.c
@@ -1309,7 +1309,7 @@  install_new_value (struct varobj *var, struct value *value, bool initial)
     {
       /* For values that are not changeable, we don't compare the values.
 	 However, we want to notice if a value was not NULL and now is NULL,
-	 or vise versa, so that we report when top-level varobjs come in scope
+	 or vice versa, so that we report when top-level varobjs come in scope
 	 and leave the scope.  */
       changed = (var->value != NULL) != (value != NULL);
     }
diff --git a/gdb/vax-tdep.c b/gdb/vax-tdep.c
index 4660979928c..64ade0a50b2 100644
--- a/gdb/vax-tdep.c
+++ b/gdb/vax-tdep.c
@@ -438,7 +438,7 @@  vax_frame_num_args (const frame_info_ptr &frame)
 
 
 
-/* Initialize the current architecture based on INFO.  If possible, re-use an
+/* Initialize the current architecture based on INFO.  If possible, reuse an
    architecture from ARCHES, which is a list of architectures already created
    during this debugging session.
 
diff --git a/gdb/windows-nat.h b/gdb/windows-nat.h
index b36e7f45512..cd253e35a5f 100644
--- a/gdb/windows-nat.h
+++ b/gdb/windows-nat.h
@@ -25,14 +25,14 @@  typedef int (segment_register_p_ftype) (int regnum);
 /* segment_register_p_ftype implementation for x86.  */
 int i386_windows_segment_register_p (int regnum);
 
-/* context register offests for x86.  */
+/* context register offsets for x86.  */
 extern const int i386_mappings[];
 
 #ifdef __x86_64__
 /* segment_register_p_ftype implementation for amd64.  */
 int amd64_windows_segment_register_p (int regnum);
 
-/* context register offests for amd64.  */
+/* context register offsets for amd64.  */
 extern const int amd64_mappings[];
 #endif
 
diff --git a/gdb/xcoffread.c b/gdb/xcoffread.c
index 2ff9d4a1775..233988d01bd 100644
--- a/gdb/xcoffread.c
+++ b/gdb/xcoffread.c
@@ -970,7 +970,7 @@  read_xcoff_symtab (struct objfile *objfile, legacy_psymtab *pst)
 
   while (symnum < max_symnum)
     {
-      QUIT;			/* make this command interruptable.  */
+      QUIT;			/* make this command interruptible.  */
 
       /* READ_ONE_SYMBOL (symbol, cs, symname_alloced); */
       /* read one symbol into `cs' structure.  After processing the
@@ -1371,7 +1371,7 @@  read_xcoff_symtab (struct objfile *objfile, legacy_psymtab *pst)
 	case C_BINCL:
 	  /* beginning of include file */
 	  /* In xlc output, C_BINCL/C_EINCL pair doesn't show up in sorted
-	     order.  Thus, when wee see them, we might not know enough info
+	     order.  Thus, when we see them, we might not know enough info
 	     to process them.  Thus, we'll be saving them into a table 
 	     (inclTable) and postpone their processing.  */
 
diff --git a/gdb/xstormy16-tdep.c b/gdb/xstormy16-tdep.c
index e7f4e6fe600..43176d969ad 100644
--- a/gdb/xstormy16-tdep.c
+++ b/gdb/xstormy16-tdep.c
@@ -435,7 +435,7 @@  xstormy16_skip_prologue (struct gdbarch *gdbarch, CORE_ADDR pc)
 	      return sal.end;
 	    }
 	}
-      /* No useable line symbol.  Use result of prologue parsing method.  */
+      /* No usable line symbol.  Use result of prologue parsing method.  */
       return plg_end;
     }
 
diff --git a/gdb/xtensa-tdep.c b/gdb/xtensa-tdep.c
index c87940c1cfc..074b7483669 100644
--- a/gdb/xtensa-tdep.c
+++ b/gdb/xtensa-tdep.c
@@ -1767,7 +1767,7 @@  xtensa_push_dummy_call (struct gdbarch *gdbarch,
 	      arg_type = builtin_type (gdbarch)->builtin_long;
 	      arg = value_cast (arg_type, arg);
 	    }
-	  /* Aligment is equal to the type length for the basic types.  */
+	  /* Alignment is equal to the type length for the basic types.  */
 	  info->align = arg_type->length ();
 	  break;
diff --git a/gdb/ada-varobj.c b/gdb/ada-varobj.c
index 21412dbf220..b188ea6351d 100644
--- a/gdb/ada-varobj.c
+++ b/gdb/ada-varobj.c
@@ -612,7 +612,7 @@  ada_varobj_describe_simple_array_child (struct value *parent_value,
     {
       std::string index_img = ada_varobj_scalar_image (index_type, real_index);
 
       /* Enumeration litterals by themselves are potentially ambiguous.
 	 For instance, consider the following package spec:
 
 	    package Pck is
@@ -620,10 +620,10 @@  ada_varobj_describe_simple_array_child (struct value *parent_value,
 	       type Blood_Cells is (White, Red);
 	    end Pck;
 
-	 In this case, the litteral "red" for instance, or even
-	 the fully-qualified litteral "pck.red" cannot be resolved
+	 In this case, the literal "red" for instance, or even
+	 the fully-qualified literal "pck.red" cannot be resolved
 	 by itself.  Type qualification is needed to determine which
-	 enumeration litterals should be used.
+	 enumeration literals should be used.
 
 	 The following variable will be used to contain the name
 	 of the array index type when such type qualification is
@@ -612,7 +612,7 @@  ada_varobj_describe_simple_array_child (struct value *parent_value,
       std::string index_img = ada_varobj_scalar_image (index_type, real_index);
 
-      /* Enumeration litterals by themselves are potentially ambiguous.
+      /* Enumeration literals by themselves are potentially ambiguous.
 	 For instance, consider the following package spec:
 